@@ -61,14 +61,14 @@ class FfmpegProcess:
             )
 
         input_file_info = FileInfoProvider(filepath)
-        duration_secs = input_file_info.get_duration()
+        duration_secs = int(input_file_info.get_duration())
 
         progress_bar = tqdm(
             total=duration_secs,
             dynamic_ncols=True
         )
 
-        progress_bar.clear()
+        #progress_bar.clear()
         previous_seconds_processed = 0
 
         try:
@@ -76,8 +76,9 @@ class FfmpegProcess:
                 line = self._process.stdout.readline().decode("utf-8")
                 # out_time_ms=3505000
                 if "out_time_ms" in line:
-                    seconds_processed = float(line[12:]) / 1000
+                    seconds_processed = int(line[12:]) / 1000
                     seconds_increase = seconds_processed - previous_seconds_processed
+                    print(seconds_increase)
                     progress_bar.update(seconds_increase)
                     previous_seconds_processed = seconds_processed
         except KeyboardInterrupt:
